/*
 * This file is part of Bipscript.
 *
 * Bipscript is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Bipscript is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Bipscript.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <chrono>
#include <thread>

#include "processorthread.h"
#include "scriptmode.h"

namespace bipscript {

void *run_output(void *arg) {
    ((ProcessorThread *)arg)->run();
    return 0;
}

void ProcessorThread::run() {
    while (true) {
        ScriptMode state = ScriptState::instance().get();
        if (state == CLOCKS_STOPPED) {
            endprocess();
            std::lock_guard<std::mutex> lock(mmutex);
            mstopped = true;
            mstoppedcv.notify_one();
            if (!mresetproof) {
                break;
            }
        } else if (state == SHUTDOWN) {
            break;
        }
        bool pactive = process();
        // store active
        mactive.store(state == MAIN_SCRIPT || pactive);
        std::this_thread::sleep_for(std::chrono::milliseconds(mperiod));
    }
}

} // namespace bipscript
