/*
 * This file is part of Bipscript.
 *
 * Bipscript is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Bipscript is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Bipscript.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef REMOTETIMESET_H
#define REMOTETIMESET_H

#include "timeline.h"

namespace bipscript {

using time::RemoteTimer;

template <class T> class RemoteTimelineSet : public TimelineSet<T> {
  public:
    void addRemote(Command *cmd, Clock &clock);
    void addRemote(Command *cmd) { addRemote(cmd, Clock::defaultClock()); }
};

// script thread
template <class T> void RemoteTimelineSet<T>::addRemote(Command *cmd, Clock &clock) {
    Timeline<T> *timeline = TimelineSet<T>::timelines[&clock];
    if (timeline == nullptr) {
        RemoteTimer &remoteClock = clock.remoteTimer();
        timeline = new Timeline<T>(remoteClock);
        TimelineSet<T>::activeList.add(timeline);
        TimelineSet<T>::timelines[&clock] = timeline;
    }
    timeline->add(cmd);
}

} // namespace bipscript
#endif // REMOTETIMESET_H
